@@ -12,6 +12,18 @@ modelstring = function(x) {
 
 }#MODELSTRING
 
+"modelstring<-" = function(x, value) {
+
+  res = model2network(value)
+
+  # check that the new network constains the same nodes as the old one.
+  if (!setequal(names(x$nodes), names(res$nodes)))
+    stop("the model string describes a different network (the nodes are different).")
+
+  return(res)
+
+}#MODELSTRING<-
+
 # bn-to-character (i.e. the model string) conversion function.
 # an alias of modelstring().
 as.character.bn = function(x, ...) {
@@ -43,4 +55,3 @@ as.bn.character = function(x, debug = FALSE) {
 
 }#AS.BN.CHARACTER
 
-
